import {
  stemTypeList,
  scoreTypeList,
  questionNumberTypeList,
  optionTypeList,
  switchOption,
  fontSizeList,
} from './common';
import { getRandomNumber } from '@/utils/index';
import { handleSplitPy } from './chinese';

export function getOption(content = '') {
  return {
    content,
    mark: getRandomNumber(),
    audio_file_id: '',
    pinyin: '',
    pinyin_item_list: [],
    hz_strokes_list: [],
  };
}
// 音频生成方式类型
export const audioGenerationMethodList = [
  {
    value: 'upload',
    label: '上传',
  },
  {
    value: 'auto',
    label: '自动生成',
  },
  {
    value: 'record',
    label: '录音',
  },
];

/**
 * 解析智能识别数据
 * @param {array} arr 智能识别数据
 * @returns object
 */
export function analysisRecognitionWordDictationData(arr) {
  let option_list = [];
  arr.map((content, index) => {
    let content_item = content.split('/');
    option_list.push({
      content: content_item[0] ? content_item[0] : '',
      mark: getRandomNumber(),
      audio_file_id: '',
      pinyin: content_item[1] ? content_item[1] : '',
      pinyin_item_list: [],
      hz_strokes_list: [],
    });
    handleSplitPy(option_list[index]);
  });

  return {
    'data.option_list': option_list,
  };
}

// 听写题数据模板
export const wordDictationData = {
  type: 'word_dictation', // 题型
  stem: '', // 题干
  description: '', // 描述
  analysis: '', // 解析，富文本
  option_number_show_mode: optionTypeList[1].value, // 选项类型
  answer: { score: 1, score_type: scoreTypeList[0].value }, // 答案
  option_list: [getOption(), getOption(), getOption()], // 选项
  file_id_list: [],
  // 题型属性
  property: {
    stem_type: stemTypeList[1].value, // 题干类型
    question_number: '1', // 题号
    stem_question_number_font_size: fontSizeList[6], // 题干题号
    is_enable_description: switchOption[1].value, // 描述
    is_enable_analysis: switchOption[1].value, // 是否开启解析
    score: 1, // 分值
    score_type: scoreTypeList[0].value, // 分值类型
  },
  // 其他属性
  other: {
    question_number_type: questionNumberTypeList[1].value, // 题号类型
    audio_generation_method: audioGenerationMethodList[0].value, // 音频生成方式
  },
};
